"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createDeleteModelCrud = void 0;
var _fullyDeleteModel = require("./fullyDeleteModel");
var _cancelDeleteModel = require("./cancelDeleteModel");
var _getDeleteModelProgress = require("./getDeleteModelProgress");
var _utils = require("@webiny/api-headless-cms/utils");
var _store = require("../helpers/store");
var _api = require("@webiny/api");
var _attachLifecycleEvents = require("./attachLifecycleEvents");
const createDeleteModelCrud = () => {
  const plugin = new _api.ContextPlugin(async context => {
    (0, _attachLifecycleEvents.attachLifecycleEvents)({
      context
    });
    const getLocale = () => {
      return context.cms.getLocale().code;
    };
    const getTenant = () => {
      return context.tenancy.getCurrentTenant().id;
    };
    const cache = (0, _utils.createMemoryCache)();
    context.cms.listModelsBeingDeleted = async () => {
      const locale = getLocale();
      const tenant = getTenant();
      const cacheKey = (0, _utils.createCacheKey)({
        tenant: getTenant(),
        locale: getLocale(),
        type: "deleteModel"
      });
      const result = await cache.getOrSet(cacheKey, async () => {
        const beginsWith = (0, _store.createStoreNamespace)({
          tenant,
          locale
        });
        return await context.db.store.listValues({
          beginsWith
        });
      });
      if (result.error) {
        throw result.error;
      } else if (!result.data) {
        return [];
      }
      return Object.values(result.data);
    };
    context.cms.isModelBeingDeleted = async modelId => {
      const items = await context.cms.listModelsBeingDeleted();
      return items.some(item => item.modelId === modelId);
    };
    context.cms.fullyDeleteModel = async modelId => {
      const result = await (0, _fullyDeleteModel.fullyDeleteModel)({
        context,
        modelId
      });
      cache.clear();
      return result;
    };
    context.cms.cancelFullyDeleteModel = async modelId => {
      const result = await (0, _cancelDeleteModel.cancelDeleteModel)({
        context,
        modelId
      });
      cache.clear();
      return result;
    };
    context.cms.getDeleteModelProgress = async modelId => {
      return await (0, _getDeleteModelProgress.getDeleteModelProgress)({
        context,
        modelId
      });
    };
  });
  plugin.name = "headlessCms.context.cms.fullyDeleteModel";
  return plugin;
};
exports.createDeleteModelCrud = createDeleteModelCrud;

//# sourceMappingURL=crud.js.map