"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createDeleteModelTask = void 0;
var _tasks = require("@webiny/tasks");
var _DeleteModelRunner = require("./DeleteModelRunner");
var _constants = require("./constants");
var _graphql = require("./graphql");
var _crud = require("./graphql/crud");
const createDefinition = () => {
  return (0, _tasks.createTaskDefinition)({
    id: _constants.DELETE_MODEL_TASK,
    disableDatabaseLogs: true,
    title: "Delete model and all of the entries",
    maxIterations: 50,
    isPrivate: true,
    async run(params) {
      try {
        const deleteModelRunner = (0, _DeleteModelRunner.createDeleteModelRunner)({
          taskId: params.store.getTask().id,
          context: params.context,
          response: params.response
        });
        return await deleteModelRunner.execute({
          input: params.input,
          isCloseToTimeout: params.isCloseToTimeout,
          isAborted: params.isAborted
        });
      } catch (ex) {
        return params.response.error(ex);
      }
    },
    createInputValidation: ({
      validator
    }) => {
      return {
        modelId: validator.string(),
        lastDeletedId: validator.string().optional()
      };
    }
  });
};
const createDeleteModelTask = () => {
  return [createDefinition(), (0, _crud.createDeleteModelCrud)(), (0, _graphql.createDeleteModelGraphQl)()];
};
exports.createDeleteModelTask = createDeleteModelTask;

//# sourceMappingURL=index.js.map